==> lighthouse-2.3.0.tgz: package/lighthouse-core/audits/accessibility/html-lang-valid.js <==
/**
 * @license Copyright 2017 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */
'use strict';

/**
 * @fileoverview Ensures the lang attribute of the <html> element has a valid value.
 * See base class in axe-audit.js for audit() implementation.
 */

const AxeAudit = require('./axe-audit');

class HTMLLangValid extends AxeAudit {
  /**
   * @return {!AuditMeta}
   */
  static get meta() {
    return {
      category: 'Accessibility',
      name: 'html-lang-valid',
      description: '`<html>` element has a valid value for its `[lang]` attribute.',
      failureDescription: '`<html>` element does not have a valid value for ' +
          'its `[lang]` attribute.',
      helpText: 'Specifying a valid [BCP 47 language](https://www.w3.org/International/questions/qa-choosing-language-tags#question) ' +
          'helps screen readers announce text properly. ' +
          '[Learn more](https://dequeuniversity.com/rules/axe/1.1/valid-lang).',
      requiredArtifacts: ['Accessibility']
    };
  }
}

module.exports = HTMLLangValid;

==> lighthouse-2.4.0.tgz: package/lighthouse-core/audits/accessibility/html-lang-valid.js <==
/**
 * @license Copyright 2017 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */
'use strict';

/**
 * @fileoverview Ensures the lang attribute of the <html> element has a valid value.
 * See base class in axe-audit.js for audit() implementation.
 */

const AxeAudit = require('./axe-audit');

class HTMLLangValid extends AxeAudit {
  /**
   * @return {!AuditMeta}
   */
  static get meta() {
    return {
      category: 'Accessibility',
      name: 'html-lang-valid',
      description: '`<html>` element has a valid value for its `[lang]` attribute.',
      failureDescription: '`<html>` element does not have a valid value for ' +
          'its `[lang]` attribute.',
      helpText: 'Specifying a valid [BCP 47 language](https://www.w3.org/International/questions/qa-choosing-language-tags#question) ' +
          'helps screen readers announce text properly. ' +
          '[Learn more](https://dequeuniversity.com/rules/axe/2.2/valid-lang?application=lighthouse).',
      requiredArtifacts: ['Accessibility']
    };
  }
}

module.exports = HTMLLangValid;
